ADHD 200


Notes
-----
Part of the the 1000 Functional Connectome Project. Phenotypic
information includes: diagnostic status, dimensional ADHD symptom measures,
age, sex, intelligence quotient (IQ) and lifetime medication status.
Preliminary quality control assessments (usable vs. questionable) based upon
visual timeseries inspection are included for all resting state fMRI scans.

Includes preprocessed data from 40 participants.

Project was coordinated by Michael P. Milham.

Content
-------
    :'func': Nifti images of the resting-state data
    :'phenotypic': Explanations of preprocessing steps
    :'confounds': CSV files containing the nuisance variables

References
----------
For more information about this dataset's structure:
http://fcon_1000.projects.nitrc.org/indi/adhd200/index.html

Licence: usage is unrestricted for non-commercial research purposes.